function [data, auxData, metaData, txtData, weights] = mydata_Chionis_minor

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Aves'; 
metaData.order      = 'Charadriiformes'; 
metaData.family     = 'Chionidae';
metaData.species    = 'Chionis_minor'; 
metaData.species_en = 'Black-faced sheathbill'; 

metaData.ecoCode.climate = {'C'};
metaData.ecoCode.ecozone = {'MIS'};
metaData.ecoCode.habitat = {'0iMi'};
metaData.ecoCode.embryo  = {'Tnsfm'};
metaData.ecoCode.migrate = {'Ms'};
metaData.ecoCode.food    = {'biO'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};

metaData.T_typical  = C2K(41); % K, body temp
metaData.data_0     = {'ab'; 'ax'; 'aR'; 'am'; 'Wwb'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Bas Kooijman'};    
metaData.date_subm = [2018 09 12];              
metaData.email    = {'bas.kooijman@vu.nl'};            
metaData.address  = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight@akvaplan.niva.no'}; 
metaData.date_acc    = [2018 09 12]; 

%% set data
% zero-variate data

data.ab = 30;      units.ab = 'd';    label.ab = 'age at birth';           bibkey.ab = 'Wiki';   
  temp.ab = C2K(37); units.temp.ab = 'K'; label.temp.ab = 'temperature';
  comment.ab = '24 to 30 d';
data.tx = 55;      units.tx = 'd';     label.tx = 'time since birth at fledging'; bibkey.tx = 'Burg1980';   
  temp.tx = C2K(41); units.temp.tx = 'K'; label.temp.tx = 'temperature';
data.tR = 365;     units.tR = 'd';    label.tR = 'time since birth at 1st brood'; bibkey.tR = 'guess';
  temp.tR = C2K(41); units.temp.tR = 'K'; label.temp.tR = 'temperature';
data.am = 20*365;  units.am = 'd';   label.am = 'life span';             bibkey.am = 'guess';   
  temp.am = C2K(41); units.temp.am = 'K'; label.temp.am = 'temperature';

data.Wwb = 25;    units.Wwb = 'g';   label.Wwb = 'wet weight at birth';     bibkey.Wwb = 'Burg1980';
data.Wwi = 635;   units.Wwi = 'g';   label.Wwi = 'ultimate wet weight for female'; bibkey.Wwi = 'Burg1980';
  comment.Wwi = 'asymptote for nestlings; adults slightly lower; Wiki: 460-730 g, with males being slightly larger than females';
  
data.Ri  = 2.5/365; units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';    bibkey.Ri  = 'Wiki';   
  temp.Ri = C2K(41); units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
  comment.Ri = '1 clutch per yr';
  
% uni-variate data
% t-W data 
data.tW = [ ... % time since birth (d), wet weight (g)
0.000	29.511
1.093	33.400
2.171	38.279
3.113	41.195
4.060	51.984
5.004	58.837
6.084	67.653
7.029	75.490
8.110	85.289
8.922	96.084
10.272	106.858
10.953	123.563
11.896	128.447
12.982	148.090
14.062	156.906
15.146	172.611
16.095	188.322
17.179	203.043
18.129	220.722
18.943	235.454
20.165	257.059
21.248	271.780
22.058	279.622
23.003	287.459
24.218	296.269
25.299	307.054
25.982	326.712
27.200	342.412
28.011	351.238
29.095	367.928
30.042	378.717
31.119	381.628
32.068	398.323
33.284	409.102
34.105	436.628
35.176	428.712
35.987	436.554
37.064	440.449
38.146	452.217
39.086	451.196
40.305	468.864
41.381	468.822
42.457	471.732
43.262	468.748
44.209	479.538
45.414	470.632
46.495	481.416
47.302	482.369
48.513	484.289
49.315	476.384
50.658	475.347
51.466	477.283
52.405	474.294
53.346	475.241
54.421	473.230
55.089	466.314];
units.tW   = {'d', 'g'};  label.tW = {'time since birth', 'wet weight'};  
temp.tW    = C2K(41);  units.temp.tW = 'K'; label.temp.tW = 'temperature';
bibkey.tW  = 'Burg1980';

%% set weights for all real data
weights = setweights(data, []);
weights.tW = 50 * weights.tW;
weights.Ri = 5 * weights.Ri;

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);
weights.psd.p_M = 10 * weights.psd.p_M;
weights.psd.v = 5 * weights.psd.v;

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

%% Discussion points
D1 = 'Body temperature is guessed';
D2 = 'food availability is reduced just after hatching and before fledging';
metaData.discussion = struct('D1', D1, 'D2', D2);

%% Acknowledgment
metaData.acknowledgment = 'The creation of this entry was support by the Norwegian Science Council (NFR 255295)';

%% Links
metaData.links.id_CoL = '69TCZ'; % Cat of Life
metaData.links.id_ITIS = '176788'; % ITIS
metaData.links.id_EoL = '1049137'; % Ency of Life
metaData.links.id_Wiki = 'Chionis_minor'; % Wikipedia
metaData.links.id_ADW = 'Chionis_minor'; % ADW
metaData.links.id_Taxo = '53766'; % Taxonomicon
metaData.links.id_WoRMS = '225982'; % WoRMS
metaData.links.id_avibase = '7C15B681DD3E8B4C'; % avibase
metaData.links.id_birdlife = 'black-faced-sheathbill-chionis-minor'; % birdlife
metaData.links.id_AnAge = ''; % AnAge


%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Chionis_minor}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Burg1980'; type = 'PhDthesis'; bib = [ ...  
'title = {Behavioural ecology of less sheatbills \emph{Chionis minor} at {M}arion {I}sland}, ' ...
'school = {Univesity of Cape Town}, ' ...
'year = {1980}, ' ...
'author = {A. E. Burger}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'EoL'; type = 'Misc'; bib = ...
'howpublished = {\url{http://genomics.senescence.info/species/entry.php?species=Chionis_minor}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];

